==> create-mdx-1.6.6.tgz: package/readme.md <==
# create-mdx

[![Build Status][build-badge]][build]
[![lerna][lerna-badge]][lerna]
[![Join the community on Spectrum][spectrum-badge]][spectrum]

Create an [MDX][] project.

## Usage

Use it directly with [`npm init`][npm]:

```sh
npm init mdx gatsby "my-new-project"
```

## API

### `npm init mdx [type=next] [name=next-mdx]`

Create a new [MDX][] project.
Defaults to the [Next][] example, but `type` can also be `create-react-app`,
`parcel`, `razzle`, or `x0`.
Name can be any name but defaults to `next-mdx`.

## Contribute

See the [Support][] and [Contributing][] guidelines on the MDX website for ways
to (get) help.

This project has a [Code of Conduct][coc].
By interacting with this repository, organisation, or community you agree to
abide by its terms.

## License

[MIT][] © [Compositor][] and [Vercel][]

<!-- Definitions -->

[build]: https://travis-ci.com/mdx-js/mdx
[build-badge]: https://travis-ci.com/mdx-js/mdx.svg?branch=master
[lerna]: https://lernajs.io/
[lerna-badge]: https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg
[spectrum]: https://spectrum.chat/mdx
[spectrum-badge]: https://withspectrum.github.io/badge/badge.svg
[contributing]: https://mdxjs.com/contributing
[support]: https://mdxjs.com/support
[coc]: https://github.com/mdx-js/.github/blob/master/code-of-conduct.md
[mit]: https://github.com/mdx-js/mdx/blob/master/license
[compositor]: https://compositor.io
[vercel]: https://vercel.com
[mdx]: https://github.com/mdx-js/mdx
[npm]: https://docs.npmjs.com/cli/init
[next]: https://github.com/mdx-js/mdx/tree/master/examples/next

==> create-mdx-1.6.22.tgz: package/readme.md <==
# create-mdx

[![Build Status][build-badge]][build]
[![lerna][lerna-badge]][lerna]
[![Chat][chat-badge]][chat]

Create an [MDX][] project.

## Usage

Use it directly with [`npm init`][npm]:

```sh
npm init mdx gatsby "my-new-project"
```

## API

### `npm init mdx [type=next] [name=next-mdx]`

Create a new [MDX][] project.
Defaults to the [Next][] example, but `type` can also be `create-react-app`,
`parcel`, `razzle`, or `x0`.
Name can be any name but defaults to `next-mdx`.

## Contribute

See the [Support][] and [Contributing][] guidelines on the MDX website for ways
to (get) help.

This project has a [Code of Conduct][coc].
By interacting with this repository, organisation, or community you agree to
abide by its terms.

## License

[MIT][] © [Compositor][] and [Vercel][]

<!-- Definitions -->

[build]: https://travis-ci.com/mdx-js/mdx
[build-badge]: https://travis-ci.com/mdx-js/mdx.svg?branch=master
[lerna]: https://lerna.js.org/
[lerna-badge]: https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg
[chat-badge]: https://img.shields.io/badge/chat-discussions-success.svg
[chat]: https://github.com/mdx-js/mdx/discussions
[contributing]: https://mdxjs.com/contributing
[support]: https://mdxjs.com/support
[coc]: https://github.com/mdx-js/.github/blob/master/code-of-conduct.md
[mit]: https://github.com/mdx-js/mdx/blob/master/license
[compositor]: https://compositor.io
[vercel]: https://vercel.com
[mdx]: https://github.com/mdx-js/mdx
[npm]: https://docs.npmjs.com/cli/init
[next]: https://github.com/mdx-js/mdx/tree/master/examples/next
